pikepdf API Reference
*********************

.. automodule:: pikepdf
    :members:

.. autoclass:: pikepdf.Pdf
    :members:

.. autoclass:: pikepdf.Object
    :members:

.. py:exception:: pikepdf.PdfError